==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Sem som',
	'aucun_document' => 'Sem documentos',
	'aucun_file' => 'Sem ficheiro',
	'aucun_image' => 'Sem imagem',
	'aucun_video' => 'Sem vídeo',
	'aucune_utilisation' => 'Este documento não é usado.',
	'aucune_vignette' => 'Sem miniatura',

	// B
	'bouton_ajouter_document' => 'ADICIONAR UM  DOCUMENTO',
	'bouton_ajouter_image' => 'ADICIONAR UMA IMAGEM',
	'bouton_ajouter_image_document' => 'Adicionar uma imagem ou um documento',
	'bouton_attacher_document' => 'Anexar',
	'bouton_copier_local' => 'Copiar no sítio',
	'bouton_download_depuis' => 'de :',
	'bouton_download_local' => 'o meu computador',
	'bouton_download_par_ftp' => 'o servidor',
	'bouton_download_par_mediatheque' => 'biblioteca multimédia',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Destacar',
	'bouton_enlever_supprimer_document' => 'Eliminar',
	'bouton_enlever_supprimer_document_confirmation' => 'Tem a certeza de que deseja eliminar o documento?',
	'bouton_modifier_document' => 'Modificar',
	'bouton_parcourir' => 'Procurar...',
	'bouton_refresh_document' => 'Actualizar o documento',
	'bouton_remplacer_document' => 'Substituir este documento',
	'bouton_remplacer_image' => 'Substituir esta imagem',
	'bouton_remplacer_image_document' => 'Substituir por uma imagem ou um documento',
	'bouton_supprimer' => 'Eliminar',
	'bouton_supprimer_tous_orphelins' => 'Eliminar todas as não usadas', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Deseja mesmo eliminar documentos órfãos @nb@ ?', # MODIF
	'bouton_upload' => 'Carregar',

	// D
	'des_audios' => '@nb@ sons',
	'des_documents' => '@nb@ documentos',
	'des_files' => '@nb@ documentos',
	'des_images' => '@nb@ imagens',
	'des_utilisations' => '@nb@ utilizações',
	'des_videos' => '@nb@ vídeos',
	'descriptif' => 'Descrição',
	'document_attache_succes' => 'O documento foi adicionado com sucesso.',
	'document_copie_locale_succes' => 'O ficheiro foi copiado para o sítio com sucesso.',
	'document_installe_succes' => 'O ficheiro foi carregado com sucesso',
	'document_vu' => 'Insrido no texto',
	'documents' => 'Biblioteca multimédia',
	'documents_brises' => 'Danificados',
	'documents_distants' => 'Remotos',
	'documents_locaux' => 'Locais',
	'documents_non_publies' => 'Não publicados',
	'documents_orphelins' => 'Não usados',
	'documents_publies' => 'Publicados',
	'documents_tous' => 'Todos',
	'double_clic_inserer_doc' => 'Faça duplo clique para inserir este atalho no texto',

	// E
	'entree_dimensions' => 'Dimensões :',
	'entree_titre_document' => 'Título do documento :',
	'entree_titre_image' => 'Título da imagem :',
	'erreur_aucun_document' => 'Este documento não existe na biblioteca multimédia',
	'erreur_aucun_fichier' => 'Nenhum ficheiro encontrado',
	'erreur_chemin_distant' => 'O ficheiro remoto @nom@ não foi encontrado',
	'erreur_chemin_ftp' => 'O ficheiro indicado não foi encontrado no servidor',
	'erreur_copie_fichier' => 'Impossível copiar o ficheiro @nom@',
	'erreur_dossier_tmp_manquant' => 'Falta uma pasta temporária para fazer download dos ficheiros',
	'erreur_ecriture_fichier' => 'Erro na escrita do ficheiro no disco',
	'erreur_format_fichier_image' => 'O formato de @nom@ não é adequado para uma imagem',
	'erreur_indiquez_un_fichier' => 'Indique um ficheiro !',
	'erreur_insertion_document_base' => 'Impossível guardar o documento @fichier@ na base de dados',
	'erreur_suppression_vignette' => 'Erro ao eliminar a miniatura',
	'erreur_upload_type_interdit' => 'O carregamento dos ficheiros do tipo @nom@ não é autorizado',
	'erreur_upload_vignette' => 'Erro no carregamento da miniatura @nom@',
	'erreurs' => '@nb@ erros',
	'erreurs_voir' => 'Visualizar os @nb@ erros',

	// F
	'fichier_distant' => 'Ficheiro remoto',
	'fichier_manquant' => 'Ficheiro em falta',
	'fichier_modifie' => 'O ficheiro foi guardado. Clique em "Guardar".',
	'format_date_incorrect' => 'A data ou a hora estão incorrectas',

	// I
	'icone_creer_document' => 'Adicionar um documento',
	'id' => 'ID',
	'image_tourner_180' => 'Rodar 180°',
	'image_tourner_droite' => 'Rodar 90° à direita',
	'image_tourner_gauche' => 'Rodar 90° à esquerda',
	'info_doc_max_poids' => 'Os documentos devem obrigatoriamente ter menos de @maxi@ (este ficheiro tem @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento não está disponível',
	'info_documents' => 'Documentos',
	'info_gauche_numero_document' => 'DOCUMENTO NÚMERO',
	'info_hauteur' => 'Altura',
	'info_heure' => 'Hora',
	'info_illustrations' => 'Ilustrações',
	'info_image_max_poids' => 'A imagens devem obrigatoriamente ter menos de @maxi@ (este ficheiro tem @actuel@).',
	'info_image_max_taille' => 'A imagens devem obrigatoriamente ter menos de @maxi@ (este ficheiro tem @actuel@).',
	'info_inclusion_directe' => 'Inclusão directa :',
	'info_inclusion_vignette' => 'Inclusão da miniatura :',
	'info_installer_tous_documents' => 'Instalar todos os documentos',
	'info_largeur' => 'Largura',
	'info_logo_max_taille' => 'Os ícones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_modifier_document' => 'Modificar o documento',
	'info_portfolio' => 'Portfólio',
	'info_referencer_doc_distant' => 'Referenciar um documento na internet :',
	'info_sans_vignette' => 'Sem miniatura',
	'info_statut_document' => 'Este documento é:',
	'info_telecharger' => 'Carregar do seu computador :',
	'infos' => 'Informações técnicas',
	'item_autoriser_selectionner_date_en_ligne' => 'Permite modificar a data de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'A data de um documento é o dia em que foi adicionado ao sítio',

	// L
	'label_activer_document_objets' => 'Activar o carregamento de documentos para o conteúdo :',
	'label_apercu' => 'Pré-visualização',
	'label_caracteristiques' => 'Características',
	'label_credits' => 'Créditos',
	'label_fichier' => 'Ficheiro',
	'label_fichier_vignette' => 'Miniatura',
	'label_paginer_par' => 'Paginado por :',
	'label_parents' => 'Este documento está ligado a',
	'label_refdoc_joindre' => 'Documento número',
	'lien_tout_enlever' => 'Eliminar tudo', # MODIF
	'logo' => 'Logo',

	// M
	'media_audio' => 'Sons',
	'media_file' => 'Outros',
	'media_image' => 'Imagens',
	'media_video' => 'Vídeos',
	'miniature_automatique_active' => 'SPIP criará automaticamente uma miniatura da imagem',

	// N
	'nb_documents_attache_succes' => '@nb@ documentos foram adicionados',
	'nb_documents_installe_succes' => '@nb@ ficheiros carregados com sucesso',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documentos',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Altura',
	'par_id' => 'ID',
	'par_largeur' => 'Largura',
	'par_taille' => 'Peso',
	'par_titre' => 'Título',

	// T
	'texte_documents_joints' => 'Pode autorizar a inclusão de documentos (ficheiros, imagens,  multimédia etc.) nos artigos e/ou nas rubricas. Estes ficheiros podem, em seguida, ser referenciados no artigo, ou exibidos separadamente.',
	'texte_documents_joints_2' => 'Esta combinação não impede a inserção de imagens directamente nos artigos nem a inclusão de documentos nos textos do conteúdo.',
	'titre_documents_joints' => 'Documentos anexados',
	'titre_page_documents_edit' => 'Modificar o documento : @titre@',
	'tous_les_medias' => 'Todos os multimédia',
	'tout_dossier_upload' => 'Todo o directório @upload@',
	'tout_voir' => 'Visualizar tudo',

	// U
	'un_audio' => '1 som',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 imagem',
	'un_video' => '1 vídeo',
	'une_utilisation' => '1 utilização',
	'upload_fichier_zip' => 'Ficheiro ZIP',
	'upload_fichier_zip_texte' => 'O ficheiro que pretende instalar é um ficheiro Zip.',
	'upload_fichier_zip_texte2' => 'Este ficheiro pode ser:',
	'upload_info_mode_document' => 'Enviar para o portfólio',
	'upload_info_mode_image' => 'Remover do portfólio',
	'upload_limit' => 'Este ficheiro é grande demais para o servidor; o tamanho máximo autorizado para <i>upload</i> é de @max@.',
	'upload_zip_conserver' => 'Conservar o ficheiro de arquivo após extrair o seu conteúdo',
	'upload_zip_decompacter' => 'expandido e cada elemento que ele contém instalado no sítio. Os ficheiros que serão então instalados são:',
	'upload_zip_mode_document' => 'Colocar todas as imagens no portfólio',
	'upload_zip_telquel' => 'instalado; como ficheiro compactado Zip;',
	'upload_zip_titrer' => 'Adicionar títulos de acordo com os nomes dos ficheiros',

	// V
	'verifier_documents_brises' => 'Verificar os ficheiros em falta',
	'verifier_documents_inutilises' => 'Verificar as ligações dos documentos',
	'vignette_supprimee' => 'A miniatura foi eliminada'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_audio' => 'Sem som',
	'aucun_document' => 'Sem documentos',
	'aucun_file' => 'Sem ficheiro',
	'aucun_image' => 'Sem imagem',
	'aucun_video' => 'Sem vídeo',
	'aucune_utilisation' => 'Este documento não é usado.',
	'aucune_vignette' => 'Sem miniatura',

	// B
	'bouton_ajouter_document' => 'ADICIONAR UM  DOCUMENTO',
	'bouton_ajouter_image' => 'ADICIONAR UMA IMAGEM',
	'bouton_ajouter_image_document' => 'Adicionar uma imagem ou um documento',
	'bouton_attacher_document' => 'Anexar',
	'bouton_copier_local' => 'Copiar no sítio',
	'bouton_download_depuis' => 'de :',
	'bouton_download_local' => 'o meu computador',
	'bouton_download_par_ftp' => 'o servidor',
	'bouton_download_par_mediatheque' => 'biblioteca multimédia',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Destacar',
	'bouton_enlever_supprimer_document' => 'Eliminar',
	'bouton_enlever_supprimer_document_confirmation' => 'Tem a certeza de que deseja eliminar o documento?',
	'bouton_modifier_document' => 'Modificar',
	'bouton_parcourir' => 'Procurar...',
	'bouton_refresh_document' => 'Actualizar o documento',
	'bouton_remplacer_document' => 'Substituir este documento',
	'bouton_remplacer_image' => 'Substituir esta imagem',
	'bouton_remplacer_image_document' => 'Substituir por uma imagem ou um documento',
	'bouton_supprimer' => 'Eliminar',
	'bouton_supprimer_tous_orphelins' => 'Eliminar todas as não usadas', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Deseja mesmo eliminar documentos órfãos @nb@ ?', # MODIF
	'bouton_upload' => 'Carregar',

	// D
	'des_audios' => '@nb@ sons',
	'des_documents' => '@nb@ documentos',
	'des_files' => '@nb@ documentos',
	'des_images' => '@nb@ imagens',
	'des_utilisations' => '@nb@ utilizações',
	'des_videos' => '@nb@ vídeos',
	'descriptif' => 'Descrição', # MODIF
	'document_attache_succes' => 'O documento foi adicionado com sucesso.',
	'document_copie_locale_succes' => 'O ficheiro foi copiado para o sítio com sucesso.',
	'document_installe_succes' => 'O ficheiro foi carregado com sucesso',
	'document_vu' => 'Insrido no texto',
	'documents' => 'Biblioteca multimédia',
	'documents_brises' => 'Danificados',
	'documents_distants' => 'Remotos',
	'documents_locaux' => 'Locais',
	'documents_non_publies' => 'Não publicados',
	'documents_orphelins' => 'Não usados',
	'documents_publies' => 'Publicados',
	'documents_tous' => 'Todos',
	'double_clic_inserer_doc' => 'Faça duplo clique para inserir este atalho no texto',

	// E
	'entree_dimensions' => 'Dimensões :',
	'entree_titre_document' => 'Título do documento :',
	'entree_titre_image' => 'Título da imagem :',
	'erreur_aucun_document' => 'Este documento não existe na biblioteca multimédia',
	'erreur_aucun_fichier' => 'Nenhum ficheiro encontrado',
	'erreur_chemin_distant' => 'O ficheiro remoto @nom@ não foi encontrado',
	'erreur_chemin_ftp' => 'O ficheiro indicado não foi encontrado no servidor',
	'erreur_copie_fichier' => 'Impossível copiar o ficheiro @nom@',
	'erreur_dossier_tmp_manquant' => 'Falta uma pasta temporária para fazer download dos ficheiros',
	'erreur_ecriture_fichier' => 'Erro na escrita do ficheiro no disco',
	'erreur_format_fichier_image' => 'O formato de @nom@ não é adequado para uma imagem',
	'erreur_indiquez_un_fichier' => 'Indique um ficheiro !',
	'erreur_insertion_document_base' => 'Impossível guardar o documento @fichier@ na base de dados',
	'erreur_suppression_vignette' => 'Erro ao eliminar a miniatura',
	'erreur_upload_type_interdit' => 'O carregamento dos ficheiros do tipo @nom@ não é autorizado',
	'erreur_upload_vignette' => 'Erro no carregamento da miniatura @nom@',
	'erreurs' => '@nb@ erros',
	'erreurs_voir' => 'Visualizar os @nb@ erros',

	// F
	'fichier_distant' => 'Ficheiro remoto',
	'fichier_manquant' => 'Ficheiro em falta',
	'fichier_modifie' => 'O ficheiro foi guardado. Clique em "Guardar".',
	'format_date_incorrect' => 'A data ou a hora estão incorrectas',

	// I
	'icone_creer_document' => 'Adicionar um documento',
	'id' => 'ID',
	'image_tourner_180' => 'Rodar 180°',
	'image_tourner_droite' => 'Rodar 90° à direita',
	'image_tourner_gauche' => 'Rodar 90° à esquerda',
	'info_doc_max_poids' => 'Os documentos devem obrigatoriamente ter menos de @maxi@ (este ficheiro tem @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento não está disponível',
	'info_documents' => 'Documentos',
	'info_gauche_numero_document' => 'DOCUMENTO NÚMERO',
	'info_hauteur' => 'Altura',
	'info_heure' => 'Hora',
	'info_illustrations' => 'Ilustrações',
	'info_image_max_poids' => 'A imagens devem obrigatoriamente ter menos de @maxi@ (este ficheiro tem @actuel@).',
	'info_image_max_taille' => 'A imagens devem obrigatoriamente ter menos de @maxi@ (este ficheiro tem @actuel@).',
	'info_inclusion_directe' => 'Inclusão directa :',
	'info_inclusion_vignette' => 'Inclusão da miniatura :',
	'info_installer_tous_documents' => 'Instalar todos os documentos',
	'info_largeur' => 'Largura',
	'info_logo_max_taille' => 'Os ícones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_modifier_document' => 'Modificar o documento',
	'info_portfolio' => 'Portfólio',
	'info_referencer_doc_distant' => 'Referenciar um documento na internet :',
	'info_sans_vignette' => 'Sem miniatura',
	'info_statut_document' => 'Este documento é:',
	'info_telecharger' => 'Carregar do seu computador :',
	'infos' => 'Informações técnicas',
	'item_autoriser_selectionner_date_en_ligne' => 'Permite modificar a data de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'A data de um documento é o dia em que foi adicionado ao sítio',

	// L
	'label_activer_document_objets' => 'Activar o carregamento de documentos para o conteúdo :',
	'label_apercu' => 'Pré-visualização',
	'label_caracteristiques' => 'Características',
	'label_credits' => 'Créditos',
	'label_fichier' => 'Ficheiro',
	'label_fichier_vignette' => 'Miniatura',
	'label_paginer_par' => 'Paginado por :',
	'label_parents' => 'Este documento está ligado a',
	'label_refdoc_joindre' => 'Documento número',
	'lien_tout_enlever' => 'Eliminar tudo', # MODIF
	'logo' => 'Logo',

	// M
	'media_audio' => 'Sons',
	'media_file' => 'Outros',
	'media_image' => 'Imagens',
	'media_video' => 'Vídeos',
	'miniature_automatique_active' => 'SPIP criará automaticamente uma miniatura da imagem',

	// N
	'nb_documents_attache_succes' => '@nb@ documentos foram adicionados',
	'nb_documents_installe_succes' => '@nb@ ficheiros carregados com sucesso',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documentos',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Altura',
	'par_id' => 'ID',
	'par_largeur' => 'Largura',
	'par_taille' => 'Peso',
	'par_titre' => 'Título',

	// T
	'texte_documents_joints' => 'Pode autorizar a inclusão de documentos (ficheiros, imagens,  multimédia etc.) nos artigos e/ou nas rubricas. Estes ficheiros podem, em seguida, ser referenciados no artigo, ou exibidos separadamente.',
	'texte_documents_joints_2' => 'Esta combinação não impede a inserção de imagens directamente nos artigos nem a inclusão de documentos nos textos do conteúdo.',
	'titre_documents_joints' => 'Documentos anexados',
	'titre_page_documents_edit' => 'Modificar o documento : @titre@',
	'tous_les_medias' => 'Todos os multimédia',
	'tout_dossier_upload' => 'Todo o directório @upload@',
	'tout_voir' => 'Visualizar tudo',

	// U
	'un_audio' => '1 som',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 imagem',
	'un_video' => '1 vídeo',
	'une_utilisation' => '1 utilização',
	'upload_fichier_zip' => 'Ficheiro ZIP',
	'upload_fichier_zip_texte' => 'O ficheiro que pretende instalar é um ficheiro Zip.',
	'upload_fichier_zip_texte2' => 'Este ficheiro pode ser:',
	'upload_info_mode_document' => 'Enviar para o portfólio',
	'upload_info_mode_image' => 'Remover do portfólio',
	'upload_limit' => 'Este ficheiro é grande demais para o servidor; o tamanho máximo autorizado para <i>upload</i> é de @max@.',
	'upload_zip_conserver' => 'Conservar o ficheiro de arquivo após extrair o seu conteúdo',
	'upload_zip_decompacter' => 'expandido e cada elemento que ele contém instalado no sítio. Os ficheiros que serão então instalados são:',
	'upload_zip_mode_document' => 'Colocar todas as imagens no portfólio',
	'upload_zip_telquel' => 'instalado; como ficheiro compactado Zip;',
	'upload_zip_titrer' => 'Adicionar títulos de acordo com os nomes dos ficheiros',

	// V
	'verifier_documents_brises' => 'Verificar os ficheiros em falta',
	'verifier_documents_inutilises' => 'Verificar as ligações dos documentos',
	'vignette_supprimee' => 'A miniatura foi eliminada',
];
